pub enum ErrorReason {
NotEnoughBytes,
TooManyBytes,
InexactByteCount,
}Expand description
How the type’s size compares to the received byte count and the transmutation function’s characteristic.
Variants
NotEnoughBytes
Too few bytes to fill even one instance of a type.
TooManyBytes
Too many bytes to fill a type.
Currently unused.
InexactByteCount
The byte amount received is not the same as the type’s size.
Implementations
Sourceimpl ErrorReason
impl ErrorReason
Sourcepub fn description(self) -> &'static str
pub fn description(self) -> &'static str
Retrieve a human readable description of the reason.