pub struct IncompatibleVecTargetError<S, T> {
pub vec: Vec<S>,
/* private fields */
}Expand description
Incompatible vector transmutation error.
Returned when the element type S does not allow a safe vector
transmutation to the target element type T. This happens when either
the size or minimum memory alignment requirements are not met:
std::mem::align_of::<S>() != std::mem::align_of::<T>()std::mem::size_of::<S>() != std::mem::size_of::<T>()
Fields
vec: Vec<S>The original vector.
Implementations
Sourceimpl<S, T> IncompatibleVecTargetError<S, T>
impl<S, T> IncompatibleVecTargetError<S, T>
Sourcepub unsafe fn copy_unchecked(&self) -> Vec<T>
pub unsafe fn copy_unchecked(&self) -> Vec<T>
Create a copy of the data, transmuted into a new vector. As the vector
will be properly aligned for accessing values of type T, this
operation will not fail due to memory alignment constraints.
Safety
The byte data in the vector needs to correspond to a valid contiguous
sequence of T values.
Sourcepub fn copy(&self) -> Vec<T>where
T: TriviallyTransmutable,
pub fn copy(&self) -> Vec<T>where
T: TriviallyTransmutable,
Create a copy of the data, transmuted into a new vector. As T is
trivially transmutable, and the new vector will be properly allocated
for accessing values of type T, this operation is safe and will never fail.